/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#include "Simikon8052.hh"

const InstructionData Simikon8052::instructionTable[ 256 ] = {
  { 1, 1, &Simikon8052::nop,   0, "nop",         0x00, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0x01, 
      0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::ljmp, &Simikon8052::ljmp_PC, "ljmp 0x%1%2", 0x02, 
      0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::rr,    0,    "rr A",     0x03, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_A, 0,    "inc A",    0x04, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::inc_IRAM, 0, "inc 0x%1", 0x05, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_INDR, 0, "inc @R0",  0x06, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_INDR, 0, "inc @R1",  0x07, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R0",   0x08, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R1",   0x09, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R2",   0x0A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R3",   0x0B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R4",   0x0C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R5",   0x0D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R6",   0x0E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::inc_DIRR, 0, "inc R7",   0x0F, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::jbc,   &Simikon8052::jbc_PC, "jbc 0x%1, 0x%2", 0x10, 
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0x11, 
      0,0,0,0,0,0 },
  { 3, 1, &Simikon8052::lcall, &Simikon8052::lcall_PC, "lcall 0x%1%2", 0x12, 
      0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::rrc,   0,    "rrc A",    0x13, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_A, 0,    "dec A",    0x14, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::dec_IRAM, 0, "dec 0x%1", 0x15, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_INDR, 0, "dec @R0",  0x16, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_INDR, 0, "dec @R1",  0x17, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R0",   0x18, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R1",   0x19, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R2",   0x1A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R3",   0x1B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R4",   0x1C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R5",   0x1D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R6",   0x1E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::dec_DIRR, 0, "dec R7",   0x1F, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::jb,   &Simikon8052::jb_PC, "jb 0x%1, 0x%2", 0x20, 
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0x21, 
      0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::ret,  &Simikon8052::ret_PC, "ret", 0x22, 
      0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::rl,       0, "rl A",         0x23, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::add_DATA, 0, "add A, #0x%1", 0x24, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::add_IRAM, 0, "add A, 0x%1",  0x25, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_INDR, 0, "add A, @R0",   0x26, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_INDR, 0, "add A, @R1",   0x27, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R0",    0x28, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R1",    0x29, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R2",    0x2A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R3",    0x2B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R4",    0x2C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R5",    0x2D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R6",    0x2E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::add_DIRR, 0, "add A, R7",    0x2F, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::jnb,   &Simikon8052::jnb_PC, "jnb 0x%1, 0x%2", 0x30, 
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0x31, 
      0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::reti,  &Simikon8052::ret_PC, "reti", 0x32, 
      0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::rlc,   0,     "rlc A",         0x33, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::addc_DATA, 0, "addc A, #0x%1", 0x34, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::addc_IRAM, 0, "addc A, 0x%1",  0x35, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_INDR, 0, "addc A, @R0",   0x36, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_INDR, 0, "addc A, @R1",   0x37, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R0",    0x38, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R1",    0x39, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R2",    0x3A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R3",    0x3B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R4",    0x3C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R5",    0x3D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R6",    0x3E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::addc_DIRR, 0, "addc A, R7",    0x3F, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::jc, &Simikon8052::jc_PC, "jc 0x%1", 0x40, 
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0x41,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::orl_IRAM_A,    0, "orl 0x%1, A",    0x42, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::orl_IRAM_DATA, 0, "orl 0x%1, #0x%2",0x43, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::orl_DATA, 0, "orl A, #0x%1", 0x44, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::orl_IRAM, 0, "orl A, 0x%1",  0x45, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_INDR, 0, "orl A, @R0",   0x46, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_INDR, 0, "orl A, @R1",   0x47, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R0",    0x48, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R1",    0x49, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R2",    0x4A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R3",    0x4B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R4",    0x4C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R5",    0x4D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R6",    0x4E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::orl_DIRR, 0, "orl A, R7",    0x4F, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::jnc, &Simikon8052::jnc_PC, "jnc 0x%1", 0x50,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0x51,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::anl_IRAM_A,    0, "anl 0x%1, A",    0x52,
      0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::anl_IRAM_DATA, 0, "anl 0x%1, #0x%2",0x53,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::anl_DATA, 0, "anl A, #0x%1", 0x54, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::anl_IRAM, 0, "anl A, 0x%1",  0x55, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_INDR, 0, "anl A, @R0",   0x56, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_INDR, 0, "anl A, @R1",   0x57, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R0",    0x58, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R1",    0x59, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R2",    0x5A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R3",    0x5B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R4",    0x5C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R5",    0x5D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R6",    0x5E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::anl_DIRR, 0, "anl A, R7",    0x5F, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::jz, &Simikon8052::jz_PC, "jz 0x%1", 0x60,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0x61,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::xrl_IRAM_A,    0, "xrl 0x%1, A",  0x62, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::xrl_IRAM_DATA, 0, "xrl 0x%1, #0x%2",0x63, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::xrl_DATA, 0, "xrl A, #0x%1", 0x64, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::xrl_IRAM, 0, "xrl A, 0x%1",  0x65, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_INDR, 0, "xrl A, @R0",   0x66, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_INDR, 0, "xrl A, @R1",   0x67, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R0",    0x68, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R1",    0x69, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R2",    0x6A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R3",    0x6B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R4",    0x6C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R5",    0x6D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R6",    0x6E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xrl_DIRR, 0, "xrl A, R7",    0x6F, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::jnz, &Simikon8052::jnz_PC, "jnz 0x%1", 0x70,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0x71,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::orl_C_BADDR, 0, "orl C, 0x%1",  0x72,     0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::jmp,         0, "jmp @A+DTPR",  0x73,     0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_A_DATA,  0, "mov A, #0x%1", 0x74,     0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::mov_IRAM_DATA, 0, "mov 0x%1, #0x%2",0x75, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_INDR_DATA, 0, "mov @R0, #0x%1", 0x76, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_INDR_DATA, 0, "mov @R1, #0x%1", 0x77, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R0, #0x%1",  0x78, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R1, #0x%1",  0x79, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R2, #0x%1",  0x7A, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R3, #0x%1",  0x7B, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R4, #0x%1",  0x7C, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R5, #0x%1",  0x7D, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R6, #0x%1",  0x7E, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_DIRR_DATA, 0, "mov R7, #0x%1",  0x7F, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::sjmp, &Simikon8052::sjmp_PC, "sjmp 0x00%1", 0x80,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0x81,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::anl_C_BADDR,   0, "anl C, 0x%1",    0x82, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::movc_PC,       0, "movc A, @A+PC",  0x83, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::div,           0, "div AB",         0x84, 0,0,0,0,0,0 },
  { 3, 1, &Simikon8052::mov_IRAM_IRAM, 0, "mov 0x%1, 0x%2", 0x85, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_INDR, 0, "mov 0x%1, @R0", 0x86, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_INDR, 0, "mov 0x%1, @R1", 0x87, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R0",  0x88, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R1",  0x89, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R2",  0x8A, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R3",  0x8B, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R4",  0x8C, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R5",  0x8D, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R6",  0x8E, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_IRAM_DIRR, 0, "mov 0x%1, R7",  0x8F, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::mov_DPTR_DATA, 0, "mov DPTR, #0x%1%2", 0x90,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0x91,
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_BADDR_C,  0, "mov 0x%1, C",    0x92, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movc_DPTR,    0, "movc A, @A+DPTR",0x93, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::subb_DATA,    0, "subb A, #0x%1",  0x94, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::subb_IRAM,    0, "subb A, 0x00%1", 0x95, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_INDR,    0, "subb A, @R0",    0x96, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_INDR,    0, "subb A, @R1",    0x97, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R0",     0x98, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R1",     0x99, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R2",     0x9A, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R3",     0x9B, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R4",     0x9C, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R5",     0x9D, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R6",     0x9E, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::subb_DIRR,    0, "subb A, R7",     0x9F, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::orl_C_bADDR,  0, "orl C, /0x%1",   0xA0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp,  &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0xA1,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_C_BADDR,   0, "mov C, 0x%1",   0xA2, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::inc_DPTR,      0, "inc DPTR",      0xA3, 0,0,0,0,0,0 },
  { 1, 4, &Simikon8052::mul_AB,        0, "mul AB",        0xA4, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::undefind,      0, "undefind",      0xA5, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_INDR_IRAM, 0, "mov @R0, 0x%1", 0xA6, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_INDR_IRAM, 0, "mov @R1, 0x%1", 0xA7, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R0, 0x%1",  0xA8, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R1, 0x%1",  0xA9, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R2, 0x%1",  0xAA, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R3, 0x%1",  0xAB, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R4, 0x%1",  0xAC, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R5, 0x%1",  0xAD, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R6, 0x%1",  0xAE, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::mov_DIRR_IRAM, 0, "mov R7, 0x%1",  0xAF, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::anl_C_bADDR,   0, "anl C, /0x%1",  0xB0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0xB1, 
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::cpl_BADDR,     0, "cpl 0x%1", 0xB2, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::cpl_C,         0, "cpl C",    0xB3, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_A_DATA, &Simikon8052::cjne_A_DATA_PC, 
      "cjne A, #0x%1, 0x%2", 0xB4, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_A_IRAM, &Simikon8052::cjne_A_IRAM_PC, 
      "cjne A, 0x%1, 0x%2",  0xB5, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_INDR_DATA, 0, "cjne @R0, #0x%1, 0x%2", 0xB6,
      0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_INDR_DATA, 0, "cjne @R1, #0x%1, 0x%2", 0xB7,
      0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R0, #0x%1, 0x%2", 0xB8, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R1, #0x%1, 0x%2", 0xB9, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R2, #0x%1, 0x%2", 0xBA, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R3, #0x%1, 0x%2", 0xBB, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R4, #0x%1, 0x%2", 0xBC, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R5, #0x%1, 0x%2", 0xBD, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R6, #0x%1, 0x%2", 0xBE, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::cjne_DIRR_DATA, &Simikon8052::cjne_DIRR_DATA_PC, 
      "cjne R7, #0x%1, 0x%2", 0xBF, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::push,           0, "push 0x%1",   0xC0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0xC1, 
      0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::clr_BADDR,      0, "clr 0x%1",    0xC2, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::clr_C,          0, "clr C",       0xC3, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::swap,           0, "swap A",      0xC4, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::xch_IRAM,       0, "xch A, 0x%1", 0xC5, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_INDR,     0, "xch A, @R0",  0xC6, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_INDR,     0, "xch A, @R1",  0xC7, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R0",   0xC8, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R1",   0xC9, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R2",   0xCA, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R3",   0xCB, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R4",   0xCC, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R5",   0xCD, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R6",   0xCE, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xch_A_DIRR,     0, "xch A, R7",   0xCF, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::pop,            0, "pop 0x%1",    0xD0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2",  0xD1,
      0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::setb_BADDR,     0, "setb 0x%1",   0xD2, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::setb_C,     0, "setb C",          0xD3, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::da,         0, "da",              0xD4, 0,0,0,0,0,0 },
  { 3, 2, &Simikon8052::djnz_IRAM,  0, "djnz 0x%1, 0x%2", 0xD5, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xchd,       0, "xchd A, @R0",     0xD6, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::xchd,       0, "xchd A, @R1",     0xD7, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R0, 0x%1", 
      0xD8, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R1, 0x%1", 
      0xD9, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R2, 0x%1", 
      0xDA, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R3, 0x%1", 
      0xDB, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R4, 0x%1", 
      0xDC, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R5, 0x%1", 
      0xDD, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R6, 0x%1", 
      0xDE, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::djnz_DIRR, &Simikon8052::djnz_DIRR_PC, "djnz R7, 0x%1", 
      0xDF, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_A_INDDPTR, 0, "movx A, @DPTR", 0xE0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::ajmp, &Simikon8052::ajmp_PC, "ajmp 0x%1%2", 0xE1, 
      0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_A_INDR,    0, "movx A, @R0",  0xE2, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_A_INDR,    0, "movx A, @R1",  0xE3, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::clr_A,          0, "clr A",        0xE4, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_A_IRAM,     0, "mov A, 0x%1",  0xE5, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_INDR,     0, "mov A, @R0",   0xE6, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_INDR,     0, "mov A, @R1",   0xE7, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R0",    0xE8, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R1",    0xE9, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R2",    0xEA, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R3",    0xEB, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R4",    0xEC, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R5",    0xED, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R6",    0xEE, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_A_DIRR,     0, "mov A, R7",    0xEF, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_INDDPTR_A, 0, "movx @DPTR+A", 0xF0, 0,0,0,0,0,0 },
  { 2, 2, &Simikon8052::acall, &Simikon8052::acall_PC, "acall 0x%1%2", 0xF1,
      0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_INDR_A,    0, "movx @R0, A", 0xF2, 0,0,0,0,0,0 },
  { 1, 2, &Simikon8052::movx_INDR_A,    0, "movx @R1, A", 0xF3, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::cpl_A,          0, "cpl A",       0xF4, 0,0,0,0,0,0 },
  { 2, 1, &Simikon8052::mov_IRAM_A,     0, "mov 0x%1",    0xF5, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_INDR_A,     0, "mov @R0, A",  0xF6, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_INDR_A,     0, "mov @R1, A",  0xF7, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R0, A",   0xF8, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R1, A",   0xF9, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R2, A",   0xFA, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R3, A",   0xFB, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R4, A",   0xFC, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R5, A",   0xFD, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R6, A",   0xFE, 0,0,0,0,0,0 },
  { 1, 1, &Simikon8052::mov_DIRR_A,     0, "mov R7, A",   0xFF, 0,0,0,0,0,0 }
};

