/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonAS31.hh"
#include "SimikonSettings.hh"
#include "SimikonUtils.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qfile.h>

// MISC_INCLUDES
#include <iostream.h>

#ifdef SIMIKON_UNIX
 #include <unistd.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <setjmp.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

// AS31_INCLUDES
#include "emitter.h"
#include "symbol.h"

// as31.y stuff
void yyparse( void );
void reset_regions( void );

// GLOBAL VARIABLES

int                  dashl;    // if "1" generate listing
FILE                *listing_fp = NULL;
FILE                *asm_fp     = NULL;
jmp_buf              main_env;

// lexer.c
extern int           lineno;

// as31.tab.c
extern int           pass;
extern int           warningno;
extern unsigned long lc;

// GLOBAL OBJECTS
extern SimikonSettings *simikonSettings;

QArray<ErrorData> errors;

/*****************************************************************************/
/* class: SimikonAS31                                                        */
/*****************************************************************************/

SimikonAS31::SimikonAS31()
{
}

SimikonAS31::~SimikonAS31()
{
}

void
SimikonAS31::assemble( ProjectData *pdata )
{
  const char *dir     = pdata->dir.ascii();
  const char *asmFile = pdata->asmFile.ascii();
  const char *hexFile = pdata->hexFile.ascii();
  const char *lstFile = pdata->lstFile.ascii();

  // open ".asm" file
  if ( (asm_fp = fopen( FFP( asmFile, dir ).ascii(), "r" )) == NULL ) {
    cout << "Can't open \".asm\" file" << endl;
    // some shit have occurred
    // ...
  }

  // listing stuff
  if ( (dashl = SS_GET_BOOL( "generate_listing" ))) {
    if ( (listing_fp = fopen( FFP( lstFile, dir ).ascii(), "w" )) == NULL ) {
      cout << "Can't open \".lst\" file" << endl;
      // some shit have occurred
      
      dashl      = 0;
      // ...
    }
  } else {
    QFile f( FFP( lstFile, dir ) );

    if ( f.exists() ) {

      if ( !f.remove() ) {
        cout << "Error removing lst file" << endl;
      }
    }
  }

  // open ".hex" file
  emitopen( FFP( hexFile, dir ).ascii(), NULL, NULL );

  bool assembled = true;

  // this is some kind of error handler
  if ( setjmp( main_env ) ) {

    emit signalSyntaxError();

    for ( uint i = 0; i < errors.count(); i++ )
      delete [] errors[ i ].message;

    errors.resize( 0 ); // clear

    assembled = false;

    goto done;
  }

  syminit();

  /* PASS 1 */

  cout << "PASS 1" << endl;

  warningno = 0;
  lineno    = 1;
  pass      = 0;
  lc        = 0x2000;

  yyparse();
  if ( warningno ) longjmp( main_env, 1 );

  /* PASS 2 */

  cout << "PASS 2" << endl;

  rewind( asm_fp );
  
  lineno    = 1;
  pass      = 1;
  lc        = 0x2000;

  emitaddr( lc );
  
  yyparse();
  if ( warningno ) longjmp( main_env, 1 );

done:
  reset_regions();
  symfree();

  // close ".asm" file
  if ( asm_fp ) { fclose( asm_fp ); asm_fp = NULL; }
  if ( listing_fp ) { fclose( listing_fp ); listing_fp = NULL; }

  // close ".hex" file
  emitclose();

  if ( assembled ) emit signalAssembled();
}
