/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef DATA_STRUCTURES_HH
#define DATA_STRUCTURES_HH

#include <qstring.h>

typedef struct {
  QString clock;
  Q_UINT8 programMemory;
} ControllerData;

typedef struct {
  Q_UINT8 iram, irom, xram, xrom;

  QString iramName, iramStart, iramEnd;
  QString iromName, iromStart, iromEnd;
  QString xramName, xramStart, xramEnd;
  QString xromName, xromStart, xromEnd;
} MemoryData;

typedef struct {
  QString author;
  QString name;
  QString hexFile;
  QString asmFile;
  QString lstFile;
  QString dir;
  QString date;

  uint address;

  ControllerData controller;
  MemoryData     memory;

  Q_UINT8 moduleState[ 10 ];

  bool isNew;
} ProjectData;

class Simikon8052;

typedef struct {
  uint bytes;  // no. of instruction bytes
  uint cycles; // no. of instruction cycles

  void ( *execute )( Simikon8052 * ); // pointer to instruction impl. function
  uint ( *PC )( Simikon8052 * ); // pointer to instruction func. for calc. PC
                                 // This is used only for branch instructions.
                                 // eg. acall, ajmp, jz, jnz, ... 
  const char *mnemonic; // mnemonic string
  uint       opCode;    // instruction op. Code
  uint       lineHEX;   // line in HEX disassembly view
  uint       lineASM;   // line in ASM disassembly view
  uint       b1, b2;    // first and second byte of instruction arguments if it
                        // has arguments at all
  bool       isBreak;   // for breakpoint
  bool       isValid;
} InstructionData;

class QListViewItem;

typedef struct {
  QListViewItem *item;
  uint          cycles;
  uint          depth;
  bool          counting;
  bool          dynamic;
} PerformanceData;

class SimikonModule;

typedef struct {
  const char    *name;
  SimikonModule *module;
} ModuleData;

typedef enum {
  INT_X0, INT_T0, INT_X1, INT_T1, INT_S
} Interrupt;

#endif // DATA_STRUCTURES_HH
