/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef REGISTER_HH
#define REGISTER_HH

#include <qwidget.h>
#include <qtable.h>

class QCheckBox;

/*===========================================================================*/
/* class: RegisterView                                                       */
/*===========================================================================*/

class RegisterView: public QTable {
  Q_OBJECT

public:
  RegisterView( QWidget *parent, const char *name );
  ~RegisterView();

  bool bitState( uint bit );

protected:
  virtual QWidget *beginEdit( int row, int col, bool replace );

public slots:
  void slotAddBit( uint bit, const QString &name, const QString &address, 
                   bool value );
  void slotUpdateBit( uint bit, bool state );

private slots:
  void SlotCheckToggled( bool state );

signals:
  void signalBitToggled( uint bit, bool state );

private:
  //  QListView *listview;
  QCheckBox *check[8];
};

/*===========================================================================*/
/* class: RegistersView                                                      */
/*===========================================================================*/

class RegistersView: public QTable {
  Q_OBJECT

public:
  RegistersView( QWidget *parent, const char *name );
  ~RegistersView();

  void setAddress( uint, const QString & );

protected:
  virtual QWidget *beginEdit( int row, int col, bool replace );
  virtual bool eventFilter( QObject *obj, QEvent *e );

public slots:
  void slotAdd( const QString &name, const QString &address );
  void slotUpdate( uint reg, const QString &value );

private slots:
  void SlotRowSelected( int row, int col );
  void SlotRowEdited( int row, int col );

signals:
  void signalValueChanged( uint row, uint value );
  void signalSelected( const QString &reg );

private:
  int editRow, editCol;
};

#endif // REGISTER_HH
