/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "config.h"
#include "SimikonAbout.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES
#include <qlayout.h>
#include <qpixmap.h>
#include <qlabel.h>
#include <qframe.h>


static const char *ABOUT_TEXT = \
 " SiMiKON " PROGRAM_VERSION "\n" \
 " Copyright (c) 1999, 2000 Alen Kovac of Tesla\n" \
 " E-Mail: Alen Kovac <akovac@jagor.srce.hr>\n" \
 "     URL: http://simikon.sourceforge.net\n";

static const char *CREDITS_TEXT = \
 " Special thanks goes to: \n\n" \
 " Tomislav Cimerman for SiMiKON splash screen.\n" \
 " Ken Stauffer for writing AS31 - 8051 assembler.\n" \
 " Dimitri van Heesch, author of QdbtTabular widget.\n" \
 " Judin Maximus, author of STabCtl widget.\n\n" \
 " Thanks to all guys at Troll Tech for abnormally cool\n" \
 " widget set - QT.\n";

extern QPixmap *simikonLogo;

/*===========================================================================*/
/* class: SimikonAbout                                                       */
/*===========================================================================*/

SimikonAbout::SimikonAbout( QWidget *parent, const char *name )
  : QDialog( parent, name, true )
{
  QVBoxLayout *topLayout = new QVBoxLayout( this );

  stabctl = new STabCtl( this );
  topLayout->addWidget( stabctl );

  SimikonAbout::InitAboutPage();
  SimikonAbout::InitCreditsPage();

  setFixedSize( 300, 205 );
}

void
SimikonAbout::InitAboutPage( void )
{
  QWidget *parent = new QWidget( stabctl );


  QVBoxLayout *topLayout = new QVBoxLayout( parent );

  QFrame *frame = new QFrame( parent );
  frame->setFrameStyle( QFrame::WinPanel | QFrame::Raised );
  frame->setLineWidth( 2 );
  topLayout->addWidget( frame );

  QVBoxLayout *layout = new QVBoxLayout( frame, 2 );
  
  // Picture
  QWidget *picture = new QWidget( frame );
  picture->setBackgroundPixmap( *simikonLogo );
  layout->addWidget( picture );
  layout->setStretchFactor( picture, 20 );

  picture->installEventFilter( this );
  
  QLabel *label = new QLabel( frame );
  layout->addWidget( label );
  layout->setStretchFactor( label, 10 );
  label->setText( tr( ABOUT_TEXT ) );

  stabctl->insertPage( parent, "About" );
}

void
SimikonAbout::InitCreditsPage( void )
{
  QWidget *parent = new QWidget( this );

  QVBoxLayout *layout = new QVBoxLayout( parent );

  QLabel *label = new QLabel( parent );
  label->setText( tr( CREDITS_TEXT ) );
  layout->addWidget( label );

  stabctl->insertPage( parent, "Credits" );
}

bool
SimikonAbout::eventFilter( QObject *, QEvent *e )
{
  if ( e->type() == QEvent::MouseButtonPress ) {
    accept();
    return true;
  }

  return false;
}
