/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_ACTIONS_HH
#define SIMIKON_ACTIONS_HH

#include <qobject.h>
#include <qdict.h>
#include <qpopupmenu.h>

// MACROS
#define SA_ENABLED(A,B) simikonActions->setActionsEnabled(A,B)
#define SA_CHECKED(A,B) simikonActions->setActionsChecked(A,B)
#define SA_IS_CHECKED(A) simikonActions->isActionChecked(A)
#define SA_IS_ENABLED(A) simikonActions->isActionEnabled(A)
#define SA_ADD_ACTION(A,B,C,D,E,F,G,H) simikonActions->addAction(A,B,C,D,E,F,G,H)
#define SA_ADD_MENU(A,B,C) simikonActions->addPopupMenu(A,B,C)
#define SA_ADD_SUB_MENU(A,B) simikonActions->addSubPopupMenu(A,B)
#define SA_ADD_TOOLBUTTONS(A,B) simikonActions->addToolButtons(A,B)
#define SA_CHANGE_TEXT(A,B) simikonActions->changeActionText(A,B)

class QMenuBar;
class QToolBar;
class QToolButton;

/*===========================================================================*/
/* struct: ActionData                                                        */
/*===========================================================================*/

struct ActionData {
  int           id;
  int           accel;
  bool          enabled;
  QString       label;
  QString       tooltiptext;
  QPixmap       *pix;
  const QObject *receiver;
  const char    *slot;
  
  QMenuBar      *menubar;
  QPopupMenu    *popupmenu;
  QToolButton   *toolbutton;
  bool          isToggle;
};

/*===========================================================================*/
/* class: SimikonActions                                                     */
/*===========================================================================*/

class SimikonActions: public QObject {
  Q_OBJECT

public:
  SimikonActions();
  ~SimikonActions();

  void addAction( const char *name, const QString &,
                  const char **pixmap,
                  const QObject *receiver, const char *slot,
                  int accel = 0, const QString &tooltiptext = QString( "" ),
                  bool isToggle = false );

  void setActionsEnabled( const char *actions, bool enabled );
  void setActionEnabled( const char *action, bool enabled );
  bool isActionEnabled( const char *action );

  void setActionsChecked( const char *actions, bool checked );
  void setActionChecked( const char *action, bool checked );
  bool isActionChecked( const char *action );

  void addMenuItems( QMenuBar *menubar, const char *data );

  void addPopupMenu( QMenuBar *menubar, const char *name, const char *data );
  void addSubPopupMenu( const char *name, const char *data );
  void addToolButtons( QToolBar *toolbar, const char *data );
  
  void setActionReceiver( const char *action, const QObject *receiver );
  void removeActionReceiver( const char *action );

  void changeActionText( const char *action, const char *text );
  
private:
  QPopupMenu   *CreateQPopupMenu( QWidget    *parent,
                                  const char *caption, 
                                  const char *data );
  ActionData   *FindActionDataByName( QString name );
  ActionData   *FindActionDataById( int id );
  ActionData   *FindActionDataByToolButton( QToolButton *toolbutton );

private slots:
  void SlotMenuItemActivated( int id );
  void SlotToolItemToggled( bool state );

private:
  QDict<ActionData> *actions;
  int               globalId;
};

#endif // SIMIKON_ACTIONS_HH
