/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_APP_HH
#define SIMIKON_APP_HH

// QT_INCLUDES
#include <qmainwindow.h>

// SIMIKON_CLASSES
class SimikonProject;
class SimikonProperties;

// QT_CLASSES
class QToolBar;
class QMenuBar;
class QStatusBar;

/*===========================================================================*/
/* class: SimikonApp                                                         */
/*===========================================================================*/

class SimikonApp: public QMainWindow {
  Q_OBJECT

public:
  SimikonApp();
  ~SimikonApp();

private:
  void InitSimikonProperties( void );
  void InitSimikonProject( void );
  void InitSimikonActions( void );
  void InitSimikonMenuBar( void );
  void InitSimikonToolBar( void );
  void InitSimikonStatusBar( void );

  void InitLatestProjectsMenu( void );

  void InitSimikonConsole( void );
  void InitSimikonProjects( void );

public slots:
  void slotQuit( void );

private slots:
  void SlotProperties( void );
  void SlotToggleToolBar( void );
  void SlotToggleStatusBar( void );
  void SlotStatusMessage( const char *msg );

protected:
  bool eventFilter( QObject *, QEvent * );
  
private:
  SimikonProject    *simikonProject;
  SimikonProperties *simikonProperties;

  QMenuBar          *menubar;
  QToolBar          *toolbar;
  QToolBar          *toolbarDebugger;
  QToolBar          *toolbarModules;
  QStatusBar        *statusbar;

  bool              showSplash;
};

#endif // SIMIKON_APP_HH
