/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */


// SIMIKON_INCLUDES
#include "SimikonConsole.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

/*===========================================================================*/
/* class: SimikonConsole                                                     */
/*===========================================================================*/

SimikonConsole::SimikonConsole( QWidget *parent, const char *name )
  : QMultiLineEdit( parent, name )
{
  setReadOnly( true );
}


SimikonConsole::~SimikonConsole()
{

}


// PUBLIC_MEMBER_FUNCTIONS
void
SimikonConsole::printMessage( const QString &msg )
{
  SimikonConsole::Print( msg, SC_MESSAGE_INFO );
}

void
SimikonConsole::printWarning( const QString &msg )
{
  SimikonConsole::Print( "Warning: " + msg, SC_MESSAGE_WARNING );
}

void
SimikonConsole::printError( const QString &msg )
{
  SimikonConsole::Print( "Error: " + msg, SC_MESSAGE_ERROR );
}

// PRIVATE_MEMBER_FUNCTIONS
void
SimikonConsole::Print( const QString &msg, MessageType type )
{
  insertLine( msg );
  setCursorPosition( numRows(), 0, false );

  STabCtl *stabctl = dynamic_cast<STabCtl *>( parent() );

  if ( stabctl->visiblePage() == this ) {
    
  } else {
    QColor color = black;

    switch ( type ) {
      case SC_MESSAGE_INFO: break;
      case SC_MESSAGE_WARNING: color = blue; break;
      case SC_MESSAGE_ERROR: color = red; break;
    }

    stabctl->setTabTextColor( this, color );
  }
}
