/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonIOPorts.hh"
#include "Simikon8052.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qlabel.h>
#include <qcheckbox.h>
#include <qlayout.h>

// WIDGETS_INCLUDES
#include "stabctl.h"

// MISC_INCLUDES
#include <iostream.h>

/*===========================================================================*/
/* class: Port                                                               */
/*===========================================================================*/

Port::Port( QWidget *parent, const char *name, const QString &portLabel )
  : QHBox( parent, name )
{

  QLabel *label;

  label = new QLabel( portLabel, this );

  for ( uint i = 0; i < 8; i++ ) {
    check[7-i] = new QCheckBox( this );
    connect( check[7-i], SIGNAL( toggled( bool ) ),
             this, SLOT( SlotCheckToggled( bool ) ) );
  }
}

Port::~Port()
{

}

void
Port::slotUpdateBit( uint bit, bool state )
{
  disconnect( check[bit], SIGNAL( toggled( bool ) ),
              this, SLOT( SlotCheckToggled( bool ) ) );

  check[bit]->setChecked( state );

  connect( check[bit], SIGNAL( toggled( bool ) ),
           this, SLOT( SlotCheckToggled( bool ) ) );
}

void
Port::SlotCheckToggled( bool state )
{
  for ( uint i = 0; i < 8; i++ )
    if ( check[i] == sender() ) {
      emit signalBitToggled( i, state );
      break;
    }
}

/*===========================================================================*/
/* class: SimikonIOPorts                                                     */
/*===========================================================================*/

SimikonIOPorts::SimikonIOPorts( QWidget *parent, const char *name, 
                                const char *action, Simikon8052 *c )
  : SimikonModule( parent, name, action )
{
  controller = c;

  InitIOPorts();

  resize( 169, 118 );
  setFixedSize( 169, 128 );
}

SimikonIOPorts::~SimikonIOPorts()
{

}

void
SimikonIOPorts::InitIOPorts( void )
{
  QWidget *parent = new QWidget( stabctl );
  QVBoxLayout *vbox = new QVBoxLayout( parent );

  QLabel *label = new QLabel( "            7  6  5  4  3  2  1  0 ", parent );
  vbox->addWidget( label );

  // Port 0
  port[ 0 ] = new Port( parent, "P0", " Port 0 " );

  connect( controller, SIGNAL( signalUpdatePXbit( uint, uint, bool ) ),
           this, SLOT( SlotUpdatePXbit( uint, uint, bool ) ) );
  connect( port[ 0 ], SIGNAL( signalBitToggled( uint, bool ) ),
           this, SLOT( SlotPXbitToggled( uint, bool ) ) );

  vbox->addWidget( port[ 0 ] );

  // Port 1
  port[ 1 ] = new Port( parent, "P1", " Port 1 " );

  connect( controller, SIGNAL( signalUpdatePXbit( uint, uint, bool ) ),
           this, SLOT( SlotUpdatePXbit( uint, uint, bool ) ) );
  connect( port[ 1 ], SIGNAL( signalBitToggled( uint, bool ) ),
           this, SLOT( SlotPXbitToggled( uint, bool ) ) );

  vbox->addWidget( port[ 1 ] );

  // Port 2
  port[ 2 ] = new Port( parent, "P2", " Port 2 " );

  connect( controller, SIGNAL( signalUpdatePXbit( uint, uint, bool ) ),
           this, SLOT( SlotUpdatePXbit( uint, uint, bool ) ) );
  connect( port[ 2 ], SIGNAL( signalBitToggled( uint, bool ) ),
           this, SLOT( SlotPXbitToggled( uint, bool ) ) );
  
  vbox->addWidget( port[ 2 ] );

  // Port 3
  port[ 3 ] = new Port( parent, "P3", " Port 3 " );

  connect( controller, SIGNAL( signalUpdatePXbit( uint, uint, bool ) ),
           this, SLOT( SlotUpdatePXbit( uint, uint, bool ) ) );
  connect( port[ 3 ], SIGNAL( signalBitToggled( uint, bool ) ),
           this, SLOT( SlotPXbitToggled( uint, bool ) ) );

  vbox->addWidget( port[ 3 ] );

  stabctl->insertPage( parent, "I/O Ports" );
}

void
SimikonIOPorts::SlotPXbitToggled( uint bit, bool state )
{
  for ( uint i = 0; i < 4; i++ ) {
    if ( sender() == port[ i ] ) {
      controller->setPXbit( i, bit, state );
      break;
    }
  }
}

void
SimikonIOPorts::SlotUpdatePXbit( uint p, uint bit, bool state )
{
  port[ p ]->slotUpdateBit( bit, state );
}
