/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_PORTS_HH
#define SIMIKON_PORTS_HH

#include "SimikonModule.hh"

#include <qhbox.h>

class Simikon8052;
class QCheckBox;

/*===========================================================================*/
/* class: Port                                                               */
/*===========================================================================*/

class Port: public QHBox {
  Q_OBJECT

public:
  Port( QWidget *parent, const char *name, const QString &label );
  ~Port();

public slots:
  void slotUpdateBit( uint bit, bool state );

private slots:
  void SlotCheckToggled( bool );

signals:
  void signalBitToggled( uint bit, bool state );

private:
  QCheckBox *check[8];

};

/*===========================================================================*/
/* class: SimikonIOPorts                                                     */
/*===========================================================================*/

class SimikonIOPorts: public SimikonModule {
  Q_OBJECT

public:
  SimikonIOPorts( QWidget *parent, const char *name, 
                  const char *action, Simikon8052 *c );
  ~SimikonIOPorts();

private:
  void InitIOPorts( void );

private slots:
  void SlotPXbitToggled( uint, bool );
  void SlotUpdatePXbit( uint, uint, bool );

private:
  Port *port[ 4 ];

  Simikon8052 *controller;
};

#endif // SIMIKON_PORTS_HH
