/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonInterrupts.hh"
#include "Simikon8052.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES
#include <qpushbutton.h>
#include <qlayout.h>

#define NO_OF_BUTTONS (4)

static const char *intTable[] = { 
  "External0", "Timer0", "External1", "Timer1" 
};


/*===========================================================================*/
/* class: SimikonInterrupts                                                  */
/*===========================================================================*/

SimikonInterrupts::SimikonInterrupts( 
   QWidget *parent, const char *name, const char *action, Simikon8052 *c )
  : SimikonModule( parent, name, action )
{
  controller = c;

  connect( controller, SIGNAL( signalEnableInterrupts( void ) ),
           this, SLOT( SlotEnableInterrupts( void ) ) );

  InitGenerateINTButtons();

  setFixedSize( 130, 153 );
}

SimikonInterrupts::~SimikonInterrupts()
{

}

void
SimikonInterrupts::InitGenerateINTButtons( void )
{
  QWidget *parent = new QWidget( stabctl, "GenerateInterrupts" );
  QVBoxLayout *layout = new QVBoxLayout( parent );

  for ( uint i = 0; i < NO_OF_BUTTONS; i++ ) {
    button[ i ] = new QPushButton( intTable[ i ], parent );

    connect( button[ i ], SIGNAL( clicked() ), 
             this, SLOT( SlotGenerateInterrupt( void ) ) );
    button[ i ]->setEnabled( false );
    layout->addWidget( button[ i ] );
  }

  stabctl->insertPage( parent, "Generate" );
}


void
SimikonInterrupts::SlotEnableInterrupts( void )
{
  if ( controller->getIEbit( 7 ) ) {
    for ( uint i = 0; i < NO_OF_BUTTONS; i++ ) {
      button[ i ]->setEnabled( controller->getIEbit( i ) );
    }
  } else {
    for ( uint i = 0; i < NO_OF_BUTTONS; i++ ) {
      button[ i ]->setEnabled( false );
    }
  }
}

void
SimikonInterrupts::SlotGenerateInterrupt( void )
{
  for ( uint i = 0; i < NO_OF_BUTTONS; i++ ) {
    if ( button[ i ] == sender() ) {
      controller->interrupt( ( Interrupt ) i );
      break;
    }
  }
}
