/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_MEMORY_HH
#define SIMIKON_MEMORY_HH

#include "SimikonModule.hh"
#include "DataStructures.hh"

#include <qtable.h>

class STabCtl;
class QLineEdit;
class QPushButton;
class QCheckBox;
class Simikon8052;

/*===========================================================================*/
/* class: MemoryItem                                                         */
/*===========================================================================*/

class MemoryItem: public QTableItem {

public:
  MemoryItem( QTable *table, EditType et, const QString &t, const QPixmap & );
  virtual ~MemoryItem();
  
  virtual int alignment() const;
};

/*===========================================================================*/
/* class: Memory                                                             */
/*===========================================================================*/

class Memory: public QTable {
  Q_OBJECT

public:
  Memory( QWidget *parent, const char *name );
  virtual ~Memory();

  void setMemory( uint _size, bool _writable );
  void setEditable( bool _editable );
  void refreshAll( uint address );

  uint getAddress( uint x, uint y );

  bool isWritable() { return writable; }

  virtual void setText( int row, int col, const QString &text );

private:
  void Refresh( uint address, uint value );
  void StartAddressChanged();

protected:
  virtual QWidget *beginEdit( int row, int col, bool replace );

public slots:  
  void slotUpdate( uint address, uint value );
  void slotClear( void );

signals:
  void signalCellEdited( int, int );

private:
  bool writable;
  bool editable;
  uint size;

  int *memory;
  uint startAddress; // adresa prvog bytea u tablici
};

/*===========================================================================*/
/* class: SimikonMemory                                                      */
/*===========================================================================*/

class SimikonMemory: public SimikonModule {
  Q_OBJECT

public:
  SimikonMemory( QWidget *parent, const char *name, 
                 const char *action, Simikon8052 *controller );
  ~SimikonMemory();

  void setActiveMemory( const MemoryData &memory );

private:
  void InitIRAM( void );
  void InitIROM( void );
  void InitXRAM( void );
  void InitXROM( void );

protected:
  bool eventFilter( QObject *, QEvent * );

private slots:
  void SlotResetMemoryView( void );
  void SlotActiveMemoryChanged( QWidget * );
  void SlotAutoToggled( bool );
  void SlotEditableToggled( bool );
  void SlotAddressChanged( const QString & );
  void SlotAddressButtonClicked( void );
  void SlotUpdateIRAM( int y, int x );

private:
  QLineEdit   *addressEntry;
  QLineEdit   *searchEntry;
  QPushButton *addressButton;
  QCheckBox   *cb1, *cb2;
  
  Memory *iram, *irom, *xram, *xrom;
  Memory *activeMemory;

  Simikon8052 *controller;
};

#endif // SIMIKON_MEMORY_HH
