/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonModule.hh"
#include "SimikonActions.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qlayout.h>

// WIDGETS_INCLUDES
#include "stabctl.h"

// MISC_INCLUDES
#include <iostream.h>

// DEFINES
#define ESCAPE_KEY (4096)

// GLOBAL_OBJECTS
extern SimikonActions *simikonActions;


/*===========================================================================*/
/* class: SimikonModule                                                      */
/*===========================================================================*/

SimikonModule::SimikonModule( QWidget *parent, const char *name, 
                              const char *action )
  : QDialog( parent, name, false )
{
  setCaption( name );

  topLayout = new QVBoxLayout( this );
	
  stabctl = new STabCtl( this );

  topLayout->addWidget( stabctl );
  topLayout->setStretchFactor( stabctl, 10 );

  actionName = new QString( action );

  installEventFilter( this );
}

SimikonModule::~SimikonModule()
{
  delete actionName;
}

bool 
SimikonModule::eventFilter( QObject *, QEvent *e )
{
  if ( e->type() == QEvent::Hide ) {
    SA_CHECKED( actionName->ascii(), false );
    emit signalClosed();
    return true;
  } else if ( e->type() == QEvent::KeyPress ) {
    if ( dynamic_cast<QKeyEvent *>( e )->key() == ESCAPE_KEY ) {
      close();
      return true;
    }
  } else if ( e->type() == QEvent::WindowActivate ) {
    setFocus();
  }
  
  return false;
}
