/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_PERFORMANCE_HH
#define SIMIKON_PERFORMANCE_HH

#include "SimikonModule.hh"

#include <qvbox.h>

class QToolBar;
class QLineEdit;
class QPushButton;
class QListView;
class QListViewItem;

class Simikon8052;

/*===========================================================================*/
/* class: Performance                                                        */
/*===========================================================================*/

class Performance: public QVBox {
  Q_OBJECT

  friend class SimikonPerformance;

public:
  Performance( QWidget *parent, const char *name );
  ~Performance();
  
  QListViewItem *add( uint address, const QString &symbol );

signals:
  void signalAdd( QListViewItem *item, bool dynamic );

private:
  QListView *listview;
};

/*===========================================================================*/
/* class: SimikonPerformance                                                 */
/*===========================================================================*/

class SimikonPerformance: public SimikonModule {
  Q_OBJECT

public:
  SimikonPerformance( QWidget *parent, const char *name, 
                      const char *action, Simikon8052 *c );
  ~SimikonPerformance();

  Performance *createPerformance( void );
  
  void setActivePerformance( Performance *performance, const char *name );
  void removeAll( void );
  void removePerformance( Performance *p );

private:
  QWidget *CreateCommands( QWidget *parent );

private slots:
  void SlotAdd( void );
  void SlotAddAuto( void );
  void SlotRemove( void );
  void SlotRemoveAll( void );
  void SlotReset( void );

signals:
  void signalAdd( QListViewItem *, bool );
  void signalAddAuto( void );
  void signalRemove( QListViewItem * );
  void signalReset( void );

private:
  QLineEdit   *start, *end;
  QPushButton *addButton, *addAutoButton, *removeButton, *removeAllButton;

  QWidget     *commands;
  
  Performance *activePerformance;

  Simikon8052 *controller;
};

#endif // SIMIKON_PERFORMANCE_HH
