/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "config.h"
#include "SimikonRegisters.hh"
#include "Simikon8052.hh"
#include "Register.hh"
#include "SimikonUtils.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES


/*===========================================================================*/
/* class: SimikonRegisters                                                   */
/*===========================================================================*/

SimikonRegisters::SimikonRegisters( QWidget *parent, const char *name, 
                                    const char *action, Simikon8052 *c )
  : SimikonModule( parent, name, action )
{
  controller = c;

  InitSFR();
  InitGPR();

  resize( 175, 212 );
  setFixedSize( 175, 212 );
}

SimikonRegisters::~SimikonRegisters()
{
}

// PUBLIC_MEMBER_FUNCTIONS

// PRIVATE_MEMBER_FUNCTIONS
void
SimikonRegisters::InitSFR( void )
{
  sfr = new RegistersView( stabctl, "SFR" );

  connect( controller, SIGNAL( signalAddSFR( const QString &, const QString & ) ),
           sfr, SLOT( slotAdd( const QString &, const QString & ) ) );
  connect( controller, SIGNAL( signalUpdateSFR( uint, const QString & ) ),
           sfr, SLOT( slotUpdate( uint, const QString & ) ) );
  connect( sfr, SIGNAL( signalSelected( const QString & ) ),
           this, SLOT( SlotSFRClicked( const QString & ) ) );
  connect( sfr, SIGNAL( signalValueChanged( uint, uint ) ),
           this, SLOT( SlotSFRChanged( uint, uint ) ) );

  stabctl->insertPage( sfr, "SFR" );
}

void
SimikonRegisters::InitGPR( void )
{
  gpr = new RegistersView( stabctl, "GPR" );

  connect( controller, SIGNAL( signalAddGPR( const QString &, const QString & ) ),
           gpr, SLOT( slotAdd( const QString &, const QString & ) ) );
  connect( controller, SIGNAL( signalUpdateGPR( uint, const QString & ) ),
           gpr, SLOT( slotUpdate( uint, const QString & ) ) );
  connect( gpr, SIGNAL( signalValueChanged( uint, uint ) ),
           this, SLOT( SlotGPRChanged( uint, uint ) ) );
  connect( controller, SIGNAL( signalUpdateRXaddresses( uint ) ),
           this, SLOT( SlotUpdateGPRaddresses( uint ) ) );

  stabctl->insertPage( gpr, "GPR" );
}

// PUBLIC_SLOTS

// PRIVATE_SLOTS
void
SimikonRegisters::SlotSFRClicked( const QString &reg )
{
  emit signalSFRClicked( reg );
}

void
SimikonRegisters::SlotSFRChanged( uint row, uint value )
{
  static uint addressTable[] = { 
    0x00, 0xE0, 0xF0, 0x81, 0x82, 0x83, 0x87, 0x98, 0x88, 0x89, 0x8A, 0x8B, 
    0x8C, 0x8D, 0x80, 0x90, 0xA0, 0xB0, 0x99, 0xA8, 0xB8, 0xD0
  };

  if ( row != 0 ) {
    controller->updateIRAM( addressTable[row], value );
  } else {
    controller->setPC( value );
  }
}

void
SimikonRegisters::SlotGPRChanged( uint row, uint value )
{
  controller->setRX( row, value );
}

void
SimikonRegisters::SlotUpdateGPRaddresses( uint start_address )
{
  for ( uint i = 0; i < 8; i++ ) {
    gpr->setAddress( i, "0x" + uintToHexStr8( start_address ) + "h" );
    start_address++;
  }
}
