/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonSFR.hh"
#include "SimikonActions.hh"
#include "Simikon8052.hh"
#include "Register.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES

// GLOBAL_OBJECTS
extern SimikonActions *simikonActions;

/*===========================================================================*/
/* class: SimikonSFR                                                         */
/*===========================================================================*/

SimikonSFR::SimikonSFR( QWidget *parent, const char *name, 
                        const char *action, Simikon8052 *cont )
  : SimikonModule( parent, name, action )
{
  controller = cont;

  InitPSW();
  InitIE();
  InitIP();
  InitSCON();
  InitPCON();
  InitTCON();
  InitTMOD();
  InitIOPorts();

  resize( 122, 212 );
  setFixedSize( 122, 212 );
}

SimikonSFR::~SimikonSFR()
{

}

// PUBLIC_MEMBER_FUNCTIONS

// PRIVATE_MEMBER_FUNCTIONS
void
SimikonSFR::InitPSW( void )
{
  psw = new RegisterView( stabctl, "PSW" );
  
  connect( controller, SIGNAL( signalAddPSWbit( uint, const QString &, const QString &, bool ) ),
           psw, SLOT( slotAddBit( uint, const QString &, const QString &, bool ) ) );
  connect( controller, SIGNAL( signalUpdatePSWbit( uint, bool ) ),
           psw, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( psw, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetPSWbit( uint, bool ) ) );
  
  stabctl->insertPage( psw, "PSW" );  
}

void
SimikonSFR::InitIE( void )
{
  ie = new RegisterView( stabctl, "IE" );

  connect( controller, SIGNAL( signalAddIEbit( uint, const QString &, const QString &, bool ) ),
           ie, SLOT( slotAddBit( uint, const QString &, const QString &, bool ) ) );
  connect( controller, SIGNAL( signalUpdateIEbit( uint, bool ) ),
           ie, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( ie, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetIEbit( uint, bool ) ) );

  stabctl->insertPage( ie, "IE" );
}

void
SimikonSFR::InitIP( void )
{
  ip = new RegisterView( stabctl, "IP" );

  connect( controller, SIGNAL( signalAddIPbit( uint, const QString &, 
                                               const QString &, bool ) ),
           ip, SLOT( slotAddBit( uint, const QString &, const QString &, bool ) ) );
  connect( controller, SIGNAL( signalUpdateIPbit( uint, bool ) ),
           ip, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( ip, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetIPbit( uint, bool ) ) );
  
  stabctl->insertPage( ip, "IP" );  
}

void
SimikonSFR::InitSCON( void )
{
  scon = new RegisterView( stabctl, "SCON" );
  
  connect( controller, SIGNAL( signalAddSCONbit( uint, 
                       const QString &, const QString &, bool ) ),
           scon, SLOT( slotAddBit( uint, 
                       const QString &, const QString &, bool ) ) );
  connect( controller, SIGNAL( signalUpdateSCONbit( uint, bool ) ),
           scon, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( scon, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetSCONbit( uint, bool ) ) );

  stabctl->insertPage( scon, "SCON" );  
}

void
SimikonSFR::InitPCON( void )
{
  pcon = new RegisterView( stabctl, "PCON" );

  connect( controller, SIGNAL( signalAddPCONbit( uint,
                       const QString &, const QString &, bool ) ),
           pcon, SLOT( slotAddBit( uint,
                 const QString &, const QString &, bool ) ) );

  connect( controller, SIGNAL( signalUpdatePCONbit( uint, bool ) ),
           pcon, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( pcon, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetPCONbit( uint, bool ) ) );

  stabctl->insertPage( pcon, "PCON" );
}

void
SimikonSFR::InitTCON( void )
{
  tcon = new RegisterView( stabctl, "TCON" );

  connect( controller, SIGNAL( signalAddTCONbit( uint,
                       const QString &, const QString &, bool ) ),
           tcon, SLOT( slotAddBit( uint,
                 const QString &, const QString &, bool ) ) );

  connect( controller, SIGNAL( signalUpdateTCONbit( uint, bool ) ),
           tcon, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( tcon, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetTCONbit( uint, bool ) ) );

  stabctl->insertPage( tcon, "TCON" );
}

void
SimikonSFR::InitTMOD( void )
{
  tmod = new RegisterView( stabctl, "TMOD" );

  connect( controller, SIGNAL( signalAddTMODbit( uint,
                       const QString &, const QString &, bool ) ),
           tmod, SLOT( slotAddBit( uint,
                 const QString &, const QString &, bool ) ) );

  connect( controller, SIGNAL( signalUpdateTMODbit( uint, bool ) ),
           tmod, SLOT( slotUpdateBit( uint, bool ) ) );
  connect( tmod, SIGNAL( signalBitToggled( uint, bool ) ),
           controller, SLOT( slotSetTMODbit( uint, bool ) ) );

  stabctl->insertPage( tmod, "TMOD" );
}

void
SimikonSFR::InitIOPorts( void )
{
  for ( uint i = 0; i < 4; i++ ) {
    QString name( QString( "P%1" ).arg( i ) );
    port[i] = new RegisterView( stabctl, name );

    connect( port[i], SIGNAL( signalBitToggled( uint, bool ) ),
             this, SLOT( SlotPXbitToggled( uint, bool ) ) );

    stabctl->insertPage( port[i], name );
  }

  connect( controller, SIGNAL( signalAddPXbit( uint, uint, 
                       const QString &, const QString &, bool ) ),
           this, SLOT( SlotAddPXbit( uint, uint,
                       const QString &, const QString &, bool ) ) );
  connect( controller, SIGNAL( signalUpdatePXbit( uint, uint, bool ) ),
           this, SLOT( SlotUpdatePXbit( uint, uint, bool ) ) );
}

int
SimikonSFR::FindPageID( const QString &sfr )
{
  QWidget *w = stabctl->getFirstPage();

  while ( w ) {

    if ( stabctl->pageCaption( w ) == sfr ) {
      return stabctl->id( w );
    }
    
    w = stabctl->getNextPage( w );
  }

  return -1;
}

// PUBLIC_SLOTS
void
SimikonSFR::slotSFRClicked( const QString &sfr )
{
  int id;

  if ( ( id = FindPageID( sfr ) ) != -1 ) {
    stabctl->setVisiblePage( id );
  }
}

// PRIVATE_SLOTS
void
SimikonSFR::SlotAddPXbit( uint p, uint bit, 
                          const QString &name, const QString &address, 
                          bool state )
{
  port[p]->slotAddBit( bit, name, address, state );
}

void
SimikonSFR::SlotUpdatePXbit( uint p, uint bit, bool state )
{
  port[p]->slotUpdateBit( bit, state );
}

void
SimikonSFR::SlotPXbitToggled( uint bit, bool state )
{
  for ( uint i = 0; i < 4; i++ ) {
    if ( sender() == port[i] ) {
      controller->setPXbit( i, bit, state );
      break;
    }
  }
}
