/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_SFR_HH
#define SIMIKON_SFR_HH

#include "SimikonModule.hh"

class Simikon8052;
class RegisterView;
class QComboBox;

/*===========================================================================*/
/* class: SimikonSFR                                                         */
/*===========================================================================*/

class SimikonSFR: public SimikonModule {
  Q_OBJECT
  
public:
  SimikonSFR( QWidget *parent, const char *name, 
              const char *action, Simikon8052 *cont );
  ~SimikonSFR();
  
private:
  void InitPSW( void );
  void InitIE( void );
  void InitIP( void );
  void InitSCON( void );
  void InitPCON( void );
  void InitTCON( void );
  void InitTMOD( void );
  void InitIOPorts( void );

  int FindPageID( const QString &sfr );
  
public slots:
  void slotSFRClicked( const QString &sfr );

private slots:
  void SlotAddPXbit( uint, uint, const QString &, const QString &, bool );
  void SlotUpdatePXbit( uint, uint, bool );
  void SlotPXbitToggled( uint, bool );

signals:
  //  void signalEnableSerialReceive( bool );
  void signalEnableSerial( bool );
  
private:
  QComboBox    *combo;
  RegisterView *psw, *ie, *ip, *scon, *pcon, *tcon, *tmod;
  RegisterView *port[5];

  Simikon8052 *controller;
};

#endif // SIMIKON_SFR_HH
