/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonSerial.hh"
#include "SimikonActions.hh"
#include "Simikon8052.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES
#include <qmultilineedit.h>
#include <qlayout.h>
#include <qevent.h>

// MISC_INCLUDES
#include <stdio.h>
#include <iostream.h>

// GLOBAL_OBJECTS
extern SimikonActions *simikonActions;

// FUNCTION_DECLARATIONS
uint keyCodeToCharacterCode( uint keyCode );

/*===========================================================================*/
/* class: Serial                                                             */
/*===========================================================================*/

SerialView::SerialView( QWidget *parent )
  : QMultiLineEdit( parent )
{
}

SerialView::~SerialView()
{
}

void
SerialView::keyPressEvent( QKeyEvent *e )
{
  if ( !isReadOnly() ) {
    emit signalKeyPressed( e->key() );
  }
}

/*===========================================================================*/
/* class: SimikonSerial                                                      */
/*===========================================================================*/

SimikonSerial::SimikonSerial( QWidget *parent, const char *name, 
                              const char *action, Simikon8052 *c )
  : SimikonModule( parent, name, action )
{
  controller = c;

  connect( controller, SIGNAL( signalEnableSerialReceive( bool ) ),
           this, SLOT( SlotEnableSerialReceive( bool ) ) );

  InitSerial();

  resize( 300, 200 );
}

SimikonSerial::~SimikonSerial()
{

}

// PUBLIC_MEMBER_FUNCTIONS

// PRIVATE_MEMBER_FUNCTIONS
void
SimikonSerial::InitSerial( void )
{
  serial = new SerialView( stabctl );
  serial->setReadOnly( true );

  connect( serial, SIGNAL( signalKeyPressed( uint ) ), this, SLOT( SlotSerialSend( uint ) ) );
  connect( controller, SIGNAL( signalSerialSend( uint ) ), this, SLOT( SlotSerialReceive( uint ) ) );
  connect( controller, SIGNAL( signalResetSerial() ), serial, SLOT( clear() ) );
  stabctl->insertPage( serial, "Serial" );
}

// PROTECTED_MEMBER_FUNCTIONS

// PUBLIC_SLOTS
void
SimikonSerial::SlotEnableSerialReceive( bool enable )
{
  serial->setReadOnly( !enable );
}

// PRIVATE SLOTS
void
SimikonSerial::SlotSerialSend( uint keyCode )
{
  uint characterCode = keyCodeToCharacterCode( keyCode );
  
  if ( characterCode != 0 ) {
    if ( !controller->getRIflag() ) {
      controller->setRIflag();
      controller->updateIRAM( SBUF, characterCode );
    }
  }
}

void
SimikonSerial::SlotSerialReceive( uint characterCode )
{
  serial->insert( QString( ( QChar ) characterCode ) );
}

/*===========================================================================*/
/* FUNCTION_DEFINITIONS                                                      */
/*===========================================================================*/

uint keyCodeToCharacterCode( uint keyCode )
{
  if ( keyCode >= 48 && keyCode <= 57 ) { // 0..9
    return keyCode;
  } else if ( keyCode >= 65 && keyCode <= 90 ) { // a..z
    return keyCode + 0x20;
  }

  return 0;
}
