/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SIMIKON_SETTINGS_HH
#define SIMIKON_SETTINGS_HH

// QT_INCLUDES
#include <qobject.h>
#include <qdict.h>

// MACROS
#define SS_PUT(A, B) simikonSettings->putEntry(A, B)
#define SS_GET(A) simikonSettings->getEntry(A)
#define SS_GET_BOOL(A) simikonSettings->getBoolEntry(A)
#define SS_GET_INT(A) simikonSettings->getIntEntry(A)
#define SS_PUT_DEFAULTS(A,B,C) simikonSettings->putDefaults(A,B,C)

/*===========================================================================*/
/* class: SimikonSettings                                                    */
/*===========================================================================*/

class SimikonSettings: public QObject {
  Q_OBJECT

public:
  SimikonSettings();
  ~SimikonSettings();

  // FUNKCIJE ZA UPISIVANJE
  void putDefaults( const char **key, const char **data, uint n );
  void putDefaults( const char **key, const int data[], uint n );

  void putEntry( const char *key, const char *value );
  void putEntry( const char *key, bool value );
  void putEntry( const char *key, int  value );

  // FUNKCIJE ZA CITANJE
  const char *getEntry( const char *key );
  bool getBoolEntry( const char *key );
  int  getIntEntry( const char *key );

  bool settingsLoaded( void ) { return isLoaded; }

private:
  void ParseSettings( void );
  void SaveSettings( void );

signals:
  void signalEntryChanged( const char *key, const char *value );

private:

  QDict<QString> *settings;
  QString settingsFile;

  bool isDirty;
  bool isLoaded;
};

#endif // SIMIKON_SETTINGS_HH
