/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonSplash.hh"
#include "SimikonSettings.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qpixmap.h>
#include <qlayout.h>
#include <qprogressbar.h>
#include <qlabel.h>

// GLOBAL_OBJECTS
extern SimikonSettings *simikonSettings;
extern QPixmap         *simikonLogo;

/*===========================================================================*/
/* class: SimikonSplash                                                      */
/*===========================================================================*/

SimikonSplash::SimikonSplash( QWidget *parent, const char *name, int steps )
  : QDialog( parent, name, false, WStyle_Customize | WStyle_NoBorder )
{
  setCaption( tr( "Loading SiMiKON..." ) );

  QVBoxLayout *layout = new QVBoxLayout( this, 2 );

  // Splash picture
  QWidget *splashPicture = new QWidget( this );
  splashPicture->setBackgroundPixmap( *simikonLogo );
  splashPicture->installEventFilter( this );

  layout->addWidget( splashPicture );
  layout->setStretchFactor( splashPicture, 10 );

  // Progress Bar
  progbar = new QProgressBar( steps, this );
  layout->addWidget( progbar );

  // Message
  message = new QLabel( "SiMiKON v1.0.11 initializing...", this );
  layout->addWidget( message );

  setFixedSize( 300, 150 );
}

SimikonSplash::~SimikonSplash()
{

}

// PUBLIC_MEMBER_FUNCTIONS

void
SimikonSplash::printMessage( const QString &msg )
{
  message->setText( msg );
  progbar->setProgress( progbar->progress() + 1 );
}

// PRIVATE_MEMBER_FUNCTIONS

void
SimikonSplash::SlotTimeout( void )
{
  accept();
}
