/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// SIMIKON_INCLUDES
#include "SimikonStack.hh"
#include "Simikon8052.hh"
#include "LeakTracker.hh"

// WIDGET_INCLUDES
#include "stabctl.h"

// QT_INCLUDES
#include <qlayout.h>

// MISC_INCLUDES
#include <iostream.h>

/*===========================================================================*/
/* class: Stack                                                              */
/*===========================================================================*/

StackView::StackView( QWidget *parent, const char *name )
  : QListView( parent, name )
{
  setSorting( -1 );
  addColumn( "Address" );
  addColumn( "Value" );
}

StackView::~StackView()
{
}

void
StackView::slotPush( const QString &address, const QString &value )
{
  new QListViewItem( this, "0x" + address, "0x" + value );
}

void
StackView::slotPop( void )
{
  removeItem( firstChild() );
}

void
StackView::slotReset( void )
{
  clear();
}

/*===========================================================================*/
/* class: SimikonStack                                                       */
/*===========================================================================*/

SimikonStack::SimikonStack( QWidget *parent, const char *name, 
                            const char *action, Simikon8052 *controller  )
  : SimikonModule( parent, name, action )
{
  InitStack( controller );
  resize( 122, 212 );
}

SimikonStack::~SimikonStack()
{

}

void
SimikonStack::InitStack( Simikon8052 *controller )
{
  stack = new StackView( stabctl, "Stack" );

  connect( controller, SIGNAL( signalPushStack( const QString &, const QString & ) ),
           stack, SLOT( slotPush( const QString &, const QString & ) ) );
  connect( controller, SIGNAL( signalPopStack( void ) ),
           stack, SLOT( slotPop( void ) ) );
  connect( controller, SIGNAL( signalResetStack( void ) ),
           stack, SLOT( slotReset( void ) ) );
  
  stabctl->insertPage( stack, "Stack" );
}
