/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */


// SIMIKON_INCLUDES
#include "config.h"
#include "SimikonUtils.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qfile.h>
#include <qtextstream.h>

#ifdef SIMIKON_UNIX
 #include <unistd.h>
 #include <pwd.h>
#endif

#ifdef SIMIKON_WIN32
 #include <stdlib.h>
#endif

QString 
uintToHexStr8( uint n )
{
  QString hexStr( QString::number( n, 16 ) );

  hexStr = hexStr.upper();

  if ( !( n > 0x0F) ) hexStr.prepend( "0" );

  return ( hexStr );
}

#include <iostream.h>

QString 
uintToHexStr16( uint b1, uint b2 )
{
  QString hexStr( QString::number( b1, 16 ) );

  if ( !( b2 > 0x0F ) ) hexStr.append( "0" );
  hexStr.append( QString::number( b2, 16 ) );

  hexStr = hexStr.upper();

  if ( !( b1 > 0x0F ) ) hexStr.prepend( "0" );

  return ( hexStr );
}

QString 
uintToHexStr16( uint n )
{
  QString hexStr( QString::number( n, 16 ) );

  hexStr = hexStr.upper();

  if ( !( n > 0x000F ) ) hexStr.prepend( "000" );
  else if ( !( n > 0x00FF ) ) hexStr.prepend( "00" );
  else if ( !( n > 0x0FFF ) ) hexStr.prepend( "0" );

  return ( hexStr );
}

uint 
strToUInt( QString str )
{
  str.remove( 0, 2 );

  bool ok;

  uint retval = str.toUInt( &ok, 16 );

  if ( !ok ) {
    return 0;
  }

  return ( retval );
}

QString 
uintToTimeStr( uint cycles, uint osc )
{
  float time = ( float ) cycles * ( 12.0 / ( float ) osc ) * 1000000;

  QString timeStr;

  if ( time > 1000000.0 ) {  // sekunde
    timeStr = timeStr.sprintf( "%3.3f", time / 1000000.0 );
    timeStr.append( "s" );
  } else if ( time > 1000.0 ) { // mili sekunde
    timeStr = timeStr.sprintf( "%3.3f", time / 1000.0 );
    timeStr.append( "ms" );
  } else { // mikro sekunde
    timeStr = timeStr.sprintf( "%3.3f", time );
    timeStr.append( "us" );
  }

  return ( timeStr );
}

QString 
stripFilePath( const QString &fileName )
{
  QString name( fileName );

  uint i = name.findRev( '/' ) + 1;

  return ( name.remove( 0, i ) );
}

QString 
stripFileName( const QString &fileName )
{
  QString path( fileName );

  uint i = path.findRev( '/' );

  return ( path.remove( i, path.length() ) );
}

#ifdef SIMIKON_UNIX

QString
fullFilePath( const QString file, const QString dir )
{
  QString fullPath;

  if ( file[0] == '/' ) {
    fullPath = file;
  } else {
    fullPath = dir + "/" + file;
  }
  
  return ( fullPath );
}

QString 
userHome( void )
{
  struct passwd *pw = getpwuid( getuid() );
  return ( QString( pw->pw_dir ) );
}

#endif // SIMIKON_UNIX

#ifdef SIMIKON_WIN32

QString
fullFilePath( const QString file, const QString dir )
{
  QString fullPath;

  if ( file[0] == 'c' && file[1] == ':' ) {
    fullPath = file;
  } else {
    fullPath = dir + "/" + file;
  }
  
  return ( fullPath );
}

QString
userHome( void )
{
  char *home = getenv( "SIMIKON_HOME" );

  if ( home )
    return ( QString( home ) );
  else
    return ( QString( "c:" ) );
}

#endif // SIMIKON_WIN32

QString 
getSymbol( const QString &asmFile, uint line )
{
  QString symbol;

  QFile fp( asmFile );

  if ( !fp.open( IO_ReadOnly ) ) {
    cout << "WARNING: getSymbol(): Can't open file: " 
         << asmFile.ascii() << endl;
    symbol = "???";
  } else {
    QTextStream tfp( &fp );
    uint currentLine = 0;
    QString lineStr;

    do {
      lineStr = tfp.readLine();
      currentLine++;
    } while ( currentLine <= line );

    symbol = lineStr.simplifyWhiteSpace();
    
    // moramo izbaciti komentar, ako postoji.
    int i = symbol.find( ';' );
    if ( i != -1 ) symbol.truncate( i );

    fp.close();
  }

  return symbol;
}
