/*
 * Copyright (C) 1999, 2000 Alen Kovac <akovac@jagor.srce.hr>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity 
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#include "config.h"

// SIMIKON_INCLUDES
#include "SimikonApp.hh"
#include "SimikonSplash.hh"
#include "SimikonActions.hh"
#include "SimikonSettings.hh"
#include "LeakTracker.hh"

// QT_INCLUDES
#include <qapplication.h>
#include <qwindowsstyle.h>

#include <iostream.h>
#include <signal.h>

// SIMIKON LOGO
#include "simikonLogo.xpm"

#define NUMBER_OF_STEPS (20) // number of progress bar update steps

class SimikonConsole;
class QProgressBar;
class QPixmap;
class QLabel;
class QLineEdit;

static void signal_handler( int signo );

// GLOBAL_OBJECTS
SimikonActions  *simikonActions  = 0;
SimikonSettings *simikonSettings = 0;
SimikonSplash   *simikonSplash   = 0;
SimikonConsole  *simikonConsole  = 0;
QProgressBar    *progress        = 0;
QPixmap         *simikonLogo     = 0;

QLabel          *cursorLabel     = 0;
QLineEdit       *searchEntry     = 0;


int main( int argc, char **argv )
{
  signal( SIGINT,  signal_handler );
  signal( SIGTERM, signal_handler );
  signal( SIGSEGV, signal_handler );


  QApplication app( argc, argv );
  app.setStyle( new QWindowsStyle() );

  QTranslator translator( &app, "SimikonTranslator" );

  simikonLogo = new QPixmap( simikonLogo_xpm );
  CHECK_PTR( simikonLogo );

  simikonActions  = new SimikonActions();
  CHECK_PTR( simikonActions );

  simikonSettings = new SimikonSettings();
  CHECK_PTR( simikonSettings );

  bool showSplash = true;

  if ( simikonSettings->settingsLoaded() ) {

    if ( SS_GET_BOOL( "use_locale" ) ) {
      QString locale( SS_GET( "locale" ) );

      if ( !locale.isEmpty() && !locale.isNull() ) {
        translator.load( locale );
        app.installTranslator( &translator );
      }
    }

    showSplash = SS_GET_BOOL( "show_splash" );
  }

  if ( showSplash ) {
    simikonSplash = new SimikonSplash( 0, "SimikonSplash", NUMBER_OF_STEPS );
    CHECK_PTR( simikonSplash );

    simikonSplash->show();
  }

  SimikonApp *simikonApp = new SimikonApp;
  CHECK_PTR( simikonApp );

  app.setMainWidget( simikonApp );
  app.connect( &app, SIGNAL( lastWindowClosed() ), 
               simikonApp, SLOT( slotQuit() ) );

  delete simikonSplash;

  simikonApp->show();

  int retval = app.exec();

  delete simikonApp;
  delete simikonActions;
  delete simikonSettings;
  delete simikonLogo;

  return retval;
}

void signal_handler( int signo )
{
  switch ( signo ) {

  case SIGTERM:
  case SIGINT:
    qApp->quit();
    break;

  case SIGSEGV:
    cout << "Oops! You have just found the bug.\n"
         << "If you can reproduce this bug, please send me bug report.\n"
         << "Thanks!\n";
    qApp->quit();
    exit( 1 );
    break;
  }
}
